filegardener
============
File gardener - file maintenance utilities - file dedup, only copy detection, prune empty dirs


.. image:: https://img.shields.io/pypi/v/filegardener.svg
   :target: https://pypi.python.org/pypi/filegardener

.. image:: https://img.shields.io/travis/smorin/filegardener/master.svg
   :target: http://travis-ci.org/smorin/filegardener

.. image:: https://readthedocs.org/projects/filegardener/badge/?version=latest
   :target: http://filegardener.readthedocs.io/en/latest/?badge=latest
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/pyversions/filegardener.svg?maxAge=2592000   

* `Github Page <https://github.com/smorin/filegardener>`_
* `Issue Tracking <https://github.com/smorin/filegardener/issues>`_


